import { StoreType } from '@/redux/store';
import {
  InitialStoreState,
  getReduxWrapperWithStore,
} from '@/utils/testing/getReduxWrapperWithStore';
import { render, screen } from '@testing-library/react';
import { initialStateFixture } from '@/redux/drawer/drawerFixture';
import { TopBar } from './TopBar.component';

const renderComponent = (initialStoreState: InitialStoreState = {}): { store: StoreType } => {
  const { Wrapper, store } = getReduxWrapperWithStore(initialStoreState);

  return (
    render(
      <Wrapper>
        <TopBar />
      </Wrapper>,
    ),
    {
      store,
    }
  );
};

describe('TopBar - component', () => {
  it('Should contain user avatar, search bar', () => {
    renderComponent();

    expect(screen.getByTestId('user-avatar')).toBeInTheDocument();
    expect(screen.getByTestId('search-bar')).toBeInTheDocument();
  });

  it('should open submaps drawer on submaps button click', () => {
    const { store } = renderComponent({ drawer: initialStateFixture });

    const button = screen.getByRole('button', { name: 'Submaps' });
    button.click();

    const { isOpen, drawerName } = store.getState().drawer;

    expect(isOpen).toBe(true);
    expect(drawerName).toBe('submaps');
  });
});
