import { twMerge } from 'tailwind-merge';
import { Icon } from '@/shared/Icon';
import { BioEntity } from '@/types/models';
import { getPinColor } from '../../../ResultsList/PinsList/PinsListItem/PinsListItem.component.utils';

interface BioEntitiesPinsListItemProps {
  name: string;
  pin: BioEntity;
}

export const BioEntitiesPinsListItem = ({
  name,
  pin,
}: BioEntitiesPinsListItemProps): JSX.Element => {
  return (
    <div className="mb-4 flex w-full flex-col gap-3 rounded-lg border-[1px] border-solid border-greyscale-500 p-4">
      <div className="flex w-full flex-row items-center gap-2">
        <Icon name="pin" className={twMerge('mr-2 shrink-0', getPinColor('bioEntity'))} />
        <p>
          {pin.stringType}: <span className="w-full font-bold">{name}</span>
        </p>
      </div>
      <p className="font-bold leading-6">
        Full name: <span className="w-full font-normal">{pin.fullName}</span>
      </p>
      <p className="font-bold leading-6">
        Symbol: <span className="w-full font-normal">{pin.symbol}</span>
      </p>
      <p className="font-bold leading-6">
        Synonyms: <span className="w-full font-normal">{pin.synonyms.join(', ')}</span>
      </p>
      <ul className="leading-6">
        <div className="font-bold">References:</div>
        {pin.references.map(reference => {
          return (
            <li key={reference.id} className="my-2 px-2">
              <a
                href={reference.article?.link}
                target="_blank"
                className="cursor-pointer text-primary-500 underline"
              >
                {reference.type} ({reference.resource})
              </a>
            </li>
          );
        })}
      </ul>
    </div>
  );
};
