import { SIZE_OF_EMPTY_ARRAY } from '@/constants/common';
import { displayDrugsList } from '@/redux/drawer/drawer.slice';
import { loadingDrugsStatusSelector, numberOfDrugsSelector } from '@/redux/drugs/drugs.selectors';
import { useAppDispatch } from '@/redux/hooks/useAppDispatch';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { AccordionItem, AccordionItemHeading, AccordionItemButton } from '@/shared/Accordion';

export const DrugsAccordion = (): JSX.Element => {
  const drugsNumber = useAppSelector(numberOfDrugsSelector);
  const drugsState = useAppSelector(loadingDrugsStatusSelector);
  const dispatch = useAppDispatch();

  const isPending = drugsState === 'pending';
  const isSucceeded = drugsState === 'succeeded';
  const isDrugsEmpty = drugsNumber === SIZE_OF_EMPTY_ARRAY;

  const onAccordionClick = (): void => {
    dispatch(displayDrugsList());
  };

  return (
    <AccordionItem>
      <AccordionItemHeading>
        <AccordionItemButton
          variant="non-expandable"
          onClick={onAccordionClick}
          disabled={isPending || isDrugsEmpty}
        >
          Drugs
          {isPending && ' (Loading...)'}
          {isSucceeded && ` (${drugsNumber})`}
        </AccordionItemButton>
      </AccordionItemHeading>
    </AccordionItem>
  );
};
