import { PinType } from '@/components/Map/Drawer/SearchDrawerWrapper/ResultsList/PinsList/PinsList.types';
import { PINS_COLORS } from '@/constants/canvas';
import { bioEntityContentFixture } from '@/models/fixtures/bioEntityContentsFixture';
import { initialMapStateFixture } from '@/redux/map/map.fixtures';
import { UsePointToProjectionResult, usePointToProjection } from '@/utils/map/usePointToProjection';
import {
  GetReduxWrapperUsingSliceReducer,
  getReduxWrapperWithStore,
} from '@/utils/testing/getReduxWrapperWithStore';
import { renderHook } from '@testing-library/react';
import { Feature } from 'ol';
import Style from 'ol/style/Style';
import { getBioEntitySingleFeature } from './getBioEntitySingleFeature';
import * as getPinStyle from './getPinStyle';

jest.mock('./getPinStyle', () => ({
  __esModule: true,
  ...jest.requireActual('./getPinStyle'),
}));

const getPinStyleSpy = jest.spyOn(getPinStyle, 'getPinStyle');

const getPointToProjection = (
  wrapper: ReturnType<GetReduxWrapperUsingSliceReducer>['Wrapper'],
): UsePointToProjectionResult => {
  const { result: usePointToProjectionHook } = renderHook(() => usePointToProjection(), {
    wrapper,
  });

  return usePointToProjectionHook.current;
};

describe('getBioEntitySingleFeature - subUtil', () => {
  const { Wrapper } = getReduxWrapperWithStore({
    map: initialMapStateFixture,
  });
  const { bioEntity } = bioEntityContentFixture;
  const pointToProjection = getPointToProjection(Wrapper);

  const value = 1448;
  const pinTypes: PinType[] = ['bioEntity', 'drugs', 'chemicals', 'mirna', 'none'];

  it.each(pinTypes)('should return instance of Feature with Style type=%s', type => {
    const result = getBioEntitySingleFeature(bioEntity, {
      pointToProjection,
      type,
      value,
    });

    expect(result).toBeInstanceOf(Feature);
    expect(result.getStyle()).toBeInstanceOf(Style);
  });

  it.each(pinTypes)('should run getPinStyle with valid args for type=%s', async type => {
    getBioEntitySingleFeature(bioEntity, {
      pointToProjection,
      type,
      value,
    });

    expect(getPinStyleSpy).toHaveBeenCalledWith({
      color: PINS_COLORS[type],
      value,
    });
  });
});
