/* eslint-disable no-magic-numbers */
import { LINE_COLOR, LINE_WIDTH } from '@/constants/canvas';
import { allReactionsSelectorOfCurrentMap } from '@/redux/reactions/reactions.selector';
import { Reaction } from '@/types/models';
import { LinePoint } from '@/types/reactions';
import { usePointToProjection } from '@/utils/map/usePointToProjection';
import Geometry from 'ol/geom/Geometry';
import VectorLayer from 'ol/layer/Vector';
import VectorSource from 'ol/source/Vector';
import Fill from 'ol/style/Fill';
import Stroke from 'ol/style/Stroke';
import Style from 'ol/style/Style';
import { useMemo } from 'react';
import { useSelector } from 'react-redux';
import { getLineFeature } from './getLineFeature';

const getReactionsLines = (reactions: Reaction[]): LinePoint[] =>
  reactions.map(({ lines }) => lines.map(({ start, end }): LinePoint => [start, end])).flat();

export const useOlMapReactionsLayer = (): VectorLayer<VectorSource<Geometry>> => {
  const pointToProjection = usePointToProjection();
  const reactions = useSelector(allReactionsSelectorOfCurrentMap);
  const reactionsLines = getReactionsLines(reactions);

  const reactionsLinesFeatures = useMemo(
    () => reactionsLines.map(linePoint => getLineFeature(linePoint, pointToProjection)),
    [reactionsLines, pointToProjection],
  );

  const vectorSource = useMemo(() => {
    return new VectorSource({
      features: [...reactionsLinesFeatures],
    });
  }, [reactionsLinesFeatures]);

  const reactionsLayer = useMemo(
    () =>
      new VectorLayer({
        source: vectorSource,
        style: new Style({
          fill: new Fill({ color: LINE_COLOR }),
          stroke: new Stroke({ color: LINE_COLOR, width: LINE_WIDTH }),
        }),
      }),
    [vectorSource],
  );

  return reactionsLayer;
};
