import Map from 'ol/Map';
import React, { MutableRefObject, useEffect, useState } from 'react';
import { MapInstance } from '../MapViewer.types';
import { useOlMapLayers } from './config/useOlMapLayers';
import { useOlMapView } from './config/useOlMapView';
import { useOlMapListeners } from './listeners/useOlMapListeners';

interface UseOlMapInput {
  target?: HTMLElement;
}
interface UseOlMapOutput {
  mapRef: MutableRefObject<null | HTMLDivElement>;
  mapInstance: MapInstance;
}

type UseOlMap = (input?: UseOlMapInput) => UseOlMapOutput;

export const useOlMap: UseOlMap = ({ target } = {}) => {
  const mapRef = React.useRef<null | HTMLDivElement>(null);
  const [mapInstance, setMapInstance] = useState<MapInstance>(undefined);
  const view = useOlMapView({ mapInstance });
  useOlMapLayers({ mapInstance });
  useOlMapListeners({ view, mapInstance });

  useEffect(() => {
    // checking if innerHTML is empty due to possibility of target element cloning by openlayers map instance
    if (!mapRef.current || mapRef.current.innerHTML !== '') {
      return;
    }

    const map = new Map({
      target: target || mapRef.current,
    });

    setMapInstance(currentMap => currentMap || map);
  }, [target]);

  return {
    mapRef,
    mapInstance,
  };
};
