import { PerfectMultiSearchParams, PerfectSearchParams } from '@/types/search';
import { createAsyncThunk } from '@reduxjs/toolkit';
import { bioEntityResponseSchema } from '@/models/bioEntityResponseSchema';
import { apiPath } from '@/redux/apiPath';
import { axiosInstanceNewAPI } from '@/services/api/utils/axiosInstance';
import { BioEntityContent, BioEntityResponse } from '@/types/models';
import { validateDataUsingZodSchema } from '@/utils/validateDataUsingZodSchema';

type GetBioEntityProps = PerfectSearchParams;

export const getBioEntity = createAsyncThunk(
  'project/getBioEntityContents',
  async ({
    searchQuery,
    isPerfectMatch,
  }: GetBioEntityProps): Promise<BioEntityContent[] | undefined> => {
    const response = await axiosInstanceNewAPI.get<BioEntityResponse>(
      apiPath.getBioEntityContentsStringWithQuery({ searchQuery, isPerfectMatch }),
    );

    const isDataValid = validateDataUsingZodSchema(response.data, bioEntityResponseSchema);

    return isDataValid ? response.data.content : undefined;
  },
);

type GetMultiBioEntityProps = PerfectMultiSearchParams;

export const getMultiBioEntity = createAsyncThunk(
  'project/getMultiBioEntity',
  async (
    { searchQueries, isPerfectMatch }: GetMultiBioEntityProps,
    { dispatch },
  ): Promise<void> => {
    const asyncGetMirnasFunctions = searchQueries.map(searchQuery =>
      dispatch(getBioEntity({ searchQuery, isPerfectMatch })),
    );

    await Promise.all(asyncGetMirnasFunctions);
  },
);
