import { drugSchema } from '@/models/drugSchema';
import { apiPath } from '@/redux/apiPath';
import { axiosInstanceNewAPI } from '@/services/api/utils/axiosInstance';
import { Drug } from '@/types/models';
import { validateDataUsingZodSchema } from '@/utils/validateDataUsingZodSchema';
import { createAsyncThunk } from '@reduxjs/toolkit';
import { z } from 'zod';

export const getDrugs = createAsyncThunk(
  'project/getDrugs',
  async (searchQuery: string): Promise<Drug[] | undefined> => {
    const response = await axiosInstanceNewAPI.get<Drug[]>(
      apiPath.getDrugsStringWithQuery(searchQuery),
    );

    const isDataValid = validateDataUsingZodSchema(response.data, z.array(drugSchema));

    return isDataValid ? response.data : undefined;
  },
);

export const getMultiDrugs = createAsyncThunk(
  'project/getMultiDrugs',
  async (searchQueries: string[], { dispatch }): Promise<void> => {
    const asyncGetDrugsFunctions = searchQueries.map(searchQuery =>
      dispatch(getDrugs(searchQuery)),
    );

    await Promise.all(asyncGetDrugsFunctions);
  },
);
